==> sumus-6.4.5-sources.jar: io/intino/sumus/graph/Filter.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Filter extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected java.lang.String label;
	protected java.lang.String username;
	protected java.util.List<io.intino.sumus.graph.Filter.Categorization> categorizationList = new java.util.ArrayList<>();

	public Filter(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.lang.String label() {
		return label;
	}

	public java.lang.String username() {
		return username;
	}

	public Filter label(java.lang.String value) {
		this.label = value;
		return (Filter) this;
	}

	public Filter username(java.lang.String value) {
		this.username = value;
		return (Filter) this;
	}

	public java.util.List<io.intino.sumus.graph.Filter.Categorization> categorizationList() {
		return java.util.Collections.unmodifiableList(categorizationList);
	}

	public io.intino.sumus.graph.Filter.Categorization categorization(int index) {
		return categorizationList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Filter.Categorization> categorizationList(java.util.function.Predicate<io.intino.sumus.graph.Filter.Categorization> predicate) {
		return categorizationList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(categorizationList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("label", new java.util.ArrayList(java.util.Collections.singletonList(this.label)));
		map.put("username", new java.util.ArrayList(java.util.Collections.singletonList(this.username)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Filter$Categorization")) this.categorizationList.add(node.as(io.intino.sumus.graph.Filter.Categorization.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Filter$Categorization")) this.categorizationList.remove(node.as(io.intino.sumus.graph.Filter.Categorization.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("label")) this.label = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("username")) this.username = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("label")) this.label = (java.lang.String) values.get(0);
		else if (name.equalsIgnoreCase("username")) this.username = (java.lang.String) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Filter.Categorization categorization(java.lang.String name) {
		    io.intino.sumus.graph.Filter.Categorization newElement = core$().graph().concept(io.intino.sumus.graph.Filter.Categorization.class).createNode(name, core$()).as(io.intino.sumus.graph.Filter.Categorization.class);
			newElement.core$().set(newElement, "name", java.util.Collections.singletonList(name));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void categorization(java.util.function.Predicate<io.intino.sumus.graph.Filter.Categorization> filter) {
			new java.util.ArrayList<>(categorizationList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Categorization extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected java.lang.String name;
		protected io.intino.sumus.CategoryMap categoryMap;

		public Categorization(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public java.lang.String name() {
			return name;
		}

		public io.intino.sumus.CategoryMap categoryMap() {
			return categoryMap;
		}

		public Categorization name(java.lang.String value) {
			this.name = value;
			return (Categorization) this;
		}

		public Categorization categoryMap(io.intino.sumus.CategoryMap value) {
			this.categoryMap = value;
			return (Categorization) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("name", new java.util.ArrayList(java.util.Collections.singletonList(this.name)));
			map.put("categoryMap", new java.util.ArrayList(java.util.Collections.singletonList(this.categoryMap)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("name")) this.name = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("categoryMap")) this.categoryMap = io.intino.tara.magritte.loaders.ObjectLoader.load(values,io.intino.sumus.CategoryMap.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("name")) this.name = (java.lang.String) values.get(0);
			else if (name.equalsIgnoreCase("categoryMap")) this.categoryMap = (io.intino.sumus.CategoryMap) values.get(0);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.0.3-sources.jar: io/intino/sumus/graph/Filter.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Filter extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected java.lang.String label;
	protected java.lang.String username;
	protected java.util.List<io.intino.sumus.graph.Filter.Categorization> categorizationList = new java.util.ArrayList<>();

	public Filter(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.lang.String label() {
		return label;
	}

	public java.lang.String username() {
		return username;
	}

	public Filter label(java.lang.String value) {
		this.label = value;
		return (Filter) this;
	}

	public Filter username(java.lang.String value) {
		this.username = value;
		return (Filter) this;
	}

	public java.util.List<io.intino.sumus.graph.Filter.Categorization> categorizationList() {
		return java.util.Collections.unmodifiableList(categorizationList);
	}

	public io.intino.sumus.graph.Filter.Categorization categorization(int index) {
		return categorizationList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Filter.Categorization> categorizationList(java.util.function.Predicate<io.intino.sumus.graph.Filter.Categorization> predicate) {
		return categorizationList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(categorizationList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("label", new java.util.ArrayList(java.util.Collections.singletonList(this.label)));
		map.put("username", new java.util.ArrayList(java.util.Collections.singletonList(this.username)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Filter$Categorization")) this.categorizationList.add(node.as(io.intino.sumus.graph.Filter.Categorization.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Filter$Categorization")) this.categorizationList.remove(node.as(io.intino.sumus.graph.Filter.Categorization.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("label")) this.label = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("username")) this.username = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("label")) this.label = (java.lang.String) values.get(0);
		else if (name.equalsIgnoreCase("username")) this.username = (java.lang.String) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Filter.Categorization categorization(java.lang.String name) {
		    io.intino.sumus.graph.Filter.Categorization newElement = core$().graph().concept(io.intino.sumus.graph.Filter.Categorization.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Filter.Categorization.class);
			newElement.core$().set(newElement, "name", java.util.Collections.singletonList(name));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void categorization(java.util.function.Predicate<io.intino.sumus.graph.Filter.Categorization> filter) {
			new java.util.ArrayList<>(categorizationList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Categorization extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected java.lang.String name;
		protected java.util.List<String> tags;

		public Categorization(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public java.lang.String name() {
			return name;
		}

		public java.util.List<String> tags() {
			return tags;
		}

		public Categorization name(java.lang.String value) {
			this.name = value;
			return (Categorization) this;
		}

		public Categorization tags(java.util.List<String> value) {
			this.tags = value;
			return (Categorization) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("name", new java.util.ArrayList(java.util.Collections.singletonList(this.name)));
			map.put("tags", new java.util.ArrayList(java.util.Collections.singletonList(this.tags)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("name")) this.name = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("tags")) this.tags = io.intino.tara.magritte.loaders.ObjectLoader.load(values,java.util.List.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("name")) this.name = (java.lang.String) values.get(0);
			else if (name.equalsIgnoreCase("tags")) this.tags = (java.util.List<String>) values.get(0);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
